==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebLayoutChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebLayoutChangeEventArgsDescription } from "./WebLayoutChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebLayoutChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLayoutChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebLayoutChangeEventArgsDescriptionMetadata.a == null) {
                WebLayoutChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLayoutChangeEventArgsDescriptionMetadata.c(WebLayoutChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebLayoutChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebLayoutChangeEventArgsDescriptionMetadata.a);
            WebDockManagerLayoutDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:LayoutChangeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebDockManagerLayout");
        }
        static d(a) {
            WebLayoutChangeEventArgsDescriptionMetadata.b(a);
            a.ad("WebLayoutChangeEventArgs", () => new WebLayoutChangeEventArgsDescription());
            a.ac("WebLayoutChangeEventArgs", WebLayoutChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebLayoutChangeEventArgsDescriptionMetadata.$t = markType(WebLayoutChangeEventArgsDescriptionMetadata, 'WebLayoutChangeEventArgsDescriptionMetadata');
    WebLayoutChangeEventArgsDescriptionMetadata.a = null;
    return WebLayoutChangeEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebLayoutChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerLayoutDescriptionMetadata } from "./WebDockManagerLayoutDescriptionMetadata";
import { WebLayoutChangeEventArgsDescription } from "./WebLayoutChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebLayoutChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebLayoutChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebLayoutChangeEventArgsDescriptionMetadata.a == null) {
                WebLayoutChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebLayoutChangeEventArgsDescriptionMetadata.c(WebLayoutChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebLayoutChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebLayoutChangeEventArgsDescriptionMetadata.a);
            WebDockManagerLayoutDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:LayoutChangeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebDockManagerLayout");
        }
        static d(a) {
            WebLayoutChangeEventArgsDescriptionMetadata.b(a);
            a.ae("WebLayoutChangeEventArgs", () => new WebLayoutChangeEventArgsDescription());
            a.ad("WebLayoutChangeEventArgs", WebLayoutChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebLayoutChangeEventArgsDescriptionMetadata.$t = markType(WebLayoutChangeEventArgsDescriptionMetadata, 'WebLayoutChangeEventArgsDescriptionMetadata');
    WebLayoutChangeEventArgsDescriptionMetadata.a = null;
    return WebLayoutChangeEventArgsDescriptionMetadata;
})();
